@@ -1,17 +1,16 @@
-# This file is part of the GNU Health GTK Client.  The COPYRIGHT file at the top level of
+# This file is part of GNU Health.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-"Options"
-import ConfigParser
+import configparser
 import optparse
 import os
 import gettext
 import logging
 import sys
 import locale
-import gtk
 
-from tryton.exceptions import TrytonError
-from tryton import __version__, SERVER_VERSION
+from gi.repository import GdkPixbuf
+
+from tryton import __version__
 
 _ = gettext.gettext
 
@@ -19,14 +18,21 @@ _ = gettext.gettext
 def get_config_dir():
     if os.name == 'nt':
         appdata = os.environ['APPDATA']
-        if not isinstance(appdata, unicode):
-            appdata = unicode(appdata, sys.getfilesystemencoding())
-        return os.path.join(appdata, '.config', 'gnuhealth',
+        if not isinstance(appdata, str):
+            appdata = str(appdata, sys.getfilesystemencoding())
+        return os.path.join(appdata, '.config', 'tryton',
                 __version__.rsplit('.', 1)[0])
     return os.path.join(os.environ['HOME'], '.config', 'gnuhealth',
             __version__.rsplit('.', 1)[0])
+
+
 if not os.path.isdir(get_config_dir()):
-    os.makedirs(get_config_dir(), 0700)
+    os.makedirs(get_config_dir(), 0o700)
+
+# Create the GNU Health plugins directory at $HOME
+GH_PLUGINS_DIR = os.path.join(os.environ['HOME'], 'gnuhealth_plugins')
+if not os.path.isdir(GH_PLUGINS_DIR):
+    os.makedirs(GH_PLUGINS_DIR, 0o700)
 
 
 class ConfigManager(object):
@@ -41,26 +47,26 @@ class ConfigManager(object):
             'login.login': 'admin',
             'login.host': demo_server,
             'login.db': demo_database,
-            'login.expanded': False,
+            'login.expanded': True,
             'client.title': 'GNU Health',
-            'client.default_width': 900,
-            'client.default_height': 750,
-            'client.modepda': False,
             'client.toolbar': 'default',
             'client.maximize': False,
             'client.save_width_height': True,
             'client.save_tree_state': True,
-            'client.fast_tabbing': True,
             'client.spellcheck': False,
             'client.lang': locale.getdefaultlocale()[0],
             'client.language_direction': 'ltr',
             'client.email': '',
             'client.can_change_accelerators': False,
             'client.limit': 1000,
+            'client.bus_timeout': 10 * 60,
+            'icon.colors': '#11b0b8',
+            'image.max_size': 10 ** 6,
             'client.cli_position' : 'top',
             'menu.pane': 200,
             'menu.expanded': True,
         }
+
         self.config = {}
         self.options = {}
         self.arguments = []
@@ -84,12 +90,6 @@ class ConfigManager(object):
         parser.add_option("-s", "--server", dest="host",
                 help=_("specify the server hostname:port"))
         opt, self.arguments = parser.parse_args()
-
-        if len(self.arguments) > 1:
-            raise TrytonError(_('Too many arguments'))
-
-        if opt.config and not os.path.isfile(opt.config):
-            raise TrytonError(_('File "%s" not found') % (opt.config,))
         self.rcfile = opt.config or os.path.join(
             get_config_dir(), 'gnuhealth-client.conf')
         self.load()
@@ -116,15 +116,16 @@ class ConfigManager(object):
 
     def save(self):
         try:
-            configparser = ConfigParser.ConfigParser()
-            for entry in self.config.keys():
+            parser = configparser.ConfigParser()
+            for entry in list(self.config.keys()):
                 if not len(entry.split('.')) == 2:
                     continue
                 section, name = entry.split('.')
-                if not configparser.has_section(section):
-                    configparser.add_section(section)
-                configparser.set(section, name, self.config[entry])
-            configparser.write(open(self.rcfile, 'wb'))
+                if not parser.has_section(section):
+                    parser.add_section(section)
+                parser.set(section, name, str(self.config[entry]))
+            with open(self.rcfile, 'w') as fp:
+                parser.write(fp)
         except IOError:
             logging.getLogger(__name__).warn(
                 _('Unable to write config file %s.')
@@ -133,10 +134,10 @@ class ConfigManager(object):
         return True
 
     def load(self):
-        configparser = ConfigParser.ConfigParser()
-        configparser.read([self.rcfile])
-        for section in configparser.sections():
-            for (name, value) in configparser.items(section):
+        parser = configparser.ConfigParser()
+        parser.read([self.rcfile])
+        for section in parser.sections():
+            for (name, value) in parser.items(section):
                 if value.lower() == 'true':
                     value = True
                 elif value.lower() == 'false':
@@ -157,12 +158,13 @@ class ConfigManager(object):
         return self.options.get(key, self.config.get(key,
             self.defaults.get(key)))
 
+
 CONFIG = ConfigManager()
 CURRENT_DIR = os.path.dirname(__file__)
 if hasattr(sys, 'frozen'):
     CURRENT_DIR = os.path.dirname(sys.executable)
-if not isinstance(CURRENT_DIR, unicode):
-    CURRENT_DIR = unicode(CURRENT_DIR, sys.getfilesystemencoding())
+if not isinstance(CURRENT_DIR, str):
+    CURRENT_DIR = str(CURRENT_DIR, sys.getfilesystemencoding())
 
 PIXMAPS_DIR = os.path.join(CURRENT_DIR, 'data', 'pixmaps', 'tryton')
 if not os.path.isdir(PIXMAPS_DIR):
@@ -171,8 +173,9 @@ if not os.path.isdir(PIXMAPS_DIR):
     PIXMAPS_DIR = pkg_resources.resource_filename(
         'tryton', 'data/pixmaps/tryton')
 
+GNUHEALTH_ICON = GdkPixbuf.Pixbuf.new_from_file(
+    os.path.join(PIXMAPS_DIR, 'gnuhealth-icon.png'))
+
 
-GNUHEALTH_ICON = gtk.gdk.pixbuf_new_from_file(
-    os.path.join(PIXMAPS_DIR, 'gnuhealth-icon.png').encode('utf-8'))
-    
 BANNER = 'banner.png'
+
