@@ -1,4 +1,4 @@
-# This file is part of the GNU Health GTK Client.  The COPYRIGHT file at the top level of
+# This file is part of GNU Health.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 import os
 from tryton.config import get_config_dir
@@ -28,10 +28,10 @@ class Fingerprints(dict):
     def save(self):
         with open(KNOWN_HOSTS_PATH, 'w') as known_hosts:
             known_hosts.writelines('%s %s' % (host, sha1)
-                    + os.linesep for host, sha1 in self.iteritems())
+                    + os.linesep for host, sha1 in self.items())
 
     def __setitem__(self, key, value):
-        assert isinstance(key, basestring)
+        assert isinstance(key, str)
         if value:
             assert len(value) == 59  # len of formated sha1
         else:
