@@ -1,4 +1,4 @@
-# This file is part of the GNU Health GTK Client.  The COPYRIGHT file at the top level of
+# This file is part of GNU Health.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 "Board"
 import gettext
@@ -7,7 +7,7 @@ from tryton.gui import Main
 from tryton.gui.window.view_board import ViewBoard
 from tryton.common import RPCExecute, RPCException
 
-from tabcontent import TabContent
+from .tabcontent import TabContent
 
 _ = gettext.gettext
 
@@ -16,7 +16,7 @@ class Board(SignalEvent, TabContent):
     'Board'
 
     def __init__(self, model, name='', **attributes):
-        super(Board, self).__init__()
+        super(Board, self).__init__(**attributes)
 
         context = attributes.get('context')
         self.view_ids = attributes.get('view_ids')
@@ -50,18 +50,18 @@ class Board(SignalEvent, TabContent):
     def sig_close(self):
         return True
 
-    def __eq__(self, value):
-        if not value:
+    def compare(self, model, attributes):
+        if not attributes:
             return False
-        if not isinstance(value, Board):
-            return False
-        return (self.model == value.model
-            and self.view_ids == value.view_ids
-            and self.board.context == value.board.context
-            and self.name == value.name)
+        return (self.model == model
+            and self.attributes.get('view_ids') == attributes.get('view_ids')
+            and self.attributes.get('context') == attributes.get('context'))
+
+    def __hash__(self):
+        return id(self)
 
     def sig_win_close(self, widget):
-        Main.get_main().sig_win_close(widget)
+        Main().sig_win_close(widget)
 
     def set_cursor(self):
         if not self.board.actions:
