@@ -1,11 +1,12 @@
-# This file is part of the GNU Health GTK Client.  The COPYRIGHT file at the top level of
+# This file is part of GNU Health.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-import gtk
 import gettext
-
 import xml.dom.minidom
+
+from gi.repository import Gtk
+
 from tryton.gui.window.view_form.view.form import Container
-from tryton.common import node_attributes, ICONFACTORY
+from tryton.common import node_attributes, IconFactory, get_align
 from .action import Action
 
 _ = gettext.gettext
@@ -24,7 +25,7 @@ class ViewBoard(object):
                 break
 
         self.attributes = node_attributes(node)
-        self.widget = self.parse(node).table
+        self.widget = self.parse(node).container
         self.widget.show_all()
 
         self._active_changed(None)
@@ -47,28 +48,29 @@ class ViewBoard(object):
         return container
 
     def _parse_image(self, node, container, attributes):
-        ICONFACTORY.register_icon(attributes['name'])
-        image = gtk.Image()
-        image.set_from_stock(attributes['name'], gtk.ICON_SIZE_DIALOG)
-        container.add(image, attributes)
+        container.add(
+            IconFactory.get_image(attributes['name'], Gtk.IconSize.DIALOG),
+            attributes)
 
     def _parse_separator(self, node, container, attributes):
-        vbox = gtk.VBox()
+        vbox = Gtk.VBox()
         if attributes.get('string'):
-            label = gtk.Label(attributes['string'])
-            label.set_alignment(float(attributes.get('xalign', 0.0)),
-                float(attributes.get('yalign', 0.5)))
-            vbox.pack_start(label)
-        vbox.pack_start(gtk.HSeparator())
+            label = Gtk.Label(label=attributes['string'])
+            label.set_halign(get_align(attributes.get('xalign', 0.0)))
+            label.set_valign(get_align(attributes.get('yalign', 0.5)))
+            vbox.pack_start(
+                label, expand=True, fill=True, padding=0)
+        vbox.pack_start(
+            Gtk.HSeparator(), expand=True, fill=True, padding=0)
         container.add(vbox, attributes)
 
     def _parse_label(self, node, container, attributes):
         if not attributes.get('string'):
             container.add(None, attributes)
             return
-        label = gtk.Label(attributes['string'])
-        label.set_alignment(float(attributes.get('xalign', 0.0)),
-            float(attributes.get('yalign', 0.5)))
+        label = Gtk.Label(label=attributes['string'])
+        label.set_halign(get_align(attributes.get('xalign', 0.0)))
+        label.set_halign(get_align(attributes.get('yalign', 0.5)))
         label.set_angle(int(attributes.get('angle', 0)))
         attributes.setdefault('xexpand', 0)
         container.add(label, attributes)
@@ -79,48 +81,48 @@ class ViewBoard(object):
     def _parse_notebook(self, node, container, attributes):
         attributes.setdefault('yexpand', True)
         attributes.setdefault('yfill', True)
-        notebook = gtk.Notebook()
+        notebook = Gtk.Notebook()
         notebook.set_scrollable(True)
         container.add(notebook, attributes)
         self.parse(node, notebook)
 
     def _parse_page(self, node, notebook, attributes):
-        tab_box = gtk.HBox(spacing=3)
+        tab_box = Gtk.HBox(spacing=3)
         if '_' not in attributes['string']:
             attributes['string'] = '_' + attributes['string']
-        label = gtk.Label(attributes['string'])
+        label = Gtk.Label(label=attributes['string'])
         label.set_use_underline(True)
-        tab_box.pack_start(label)
+        tab_box.pack_start(label, expand=True, fill=True, padding=0)
 
         if 'icon' in attributes:
-            ICONFACTORY.register_icon(attributes['icon'])
-            pixbuf = tab_box.render_icon(attributes['icon'],
-                gtk.ICON_SIZE_SMALL_TOOLBAR)
-            icon = gtk.Image()
-            icon.set_from_pixbuf(pixbuf)
-            tab_box.pack_start(icon)
+            tab_box.pack_start(IconFactory.get_image(
+                    attributes['icon'], Gtk.IconSize.SMALL_TOOLBAR),
+                expand=True, fill=True, padding=0)
         tab_box.show_all()
 
-        viewport = gtk.Viewport()
-        viewport.set_shadow_type(gtk.SHADOW_NONE)
-        scrolledwindow = gtk.ScrolledWindow()
-        scrolledwindow.set_shadow_type(gtk.SHADOW_NONE)
-        scrolledwindow.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
+        viewport = Gtk.Viewport()
+        viewport.set_shadow_type(Gtk.ShadowType.NONE)
+        scrolledwindow = Gtk.ScrolledWindow()
+        scrolledwindow.set_shadow_type(Gtk.ShadowType.NONE)
+        scrolledwindow.set_policy(
+            Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
         scrolledwindow.add(viewport)
         scrolledwindow.show_all()
         notebook.append_page(scrolledwindow, tab_box)
         container = self.parse(node)
-        viewport.add(container.table)
+        viewport.add(container.container)
 
     def _parse_group(self, node, container, attributes):
         group = self.parse(node)
-        group.table.set_homogeneous(attributes.get('homogeneous', False))
-        frame = gtk.Frame()
+        homogeneous = bool(attributes.get('homogeneous', False))
+        group.container.set_column_homogeneous(homogeneous)
+        group.container.set_row_homogeneous(homogeneous)
+        frame = Gtk.Frame()
         frame.set_label(attributes.get('string'))
         if not attributes.get('string'):
-            frame.set_shadow_type(gtk.SHADOW_NONE)
+            frame.set_shadow_type(Gtk.ShadowType.NONE)
         frame.set_border_width(0)
-        frame.add(group.table)
+        frame.add(group.container)
         container.add(frame, attributes)
 
     def _parse_paned(self, node, container, attributes, Paned):
@@ -133,10 +135,10 @@ class ViewBoard(object):
         self.parse(node, paned)
 
     def _parse_hpaned(self, node, container, attributes):
-        self._parse_paned(node, container, attributes, gtk.HPaned)
+        self._parse_paned(node, container, attributes, Gtk.HPaned)
 
     def _parse_vpaned(self, node, container, attributes):
-        self._parse_paned(node, container, attributes, gtk.VPaned)
+        self._parse_paned(node, container, attributes, Gtk.VPaned)
 
     def _parse_child(self, node, paned, attributes):
         container = self.parse(node)
@@ -144,7 +146,7 @@ class ViewBoard(object):
             pack = paned.pack1
         else:
             pack = paned.pack2
-        pack(container.table, resize=True, shrink=True)
+        pack(container.container, resize=True, shrink=True)
 
     def _parse_action(self, node, container, attributes):
         attributes.setdefault('yexpand', True)
