@@ -1,12 +1,15 @@
-# This file is part of the GNU Health GTK Client.  The COPYRIGHT file at the top level of
+# This file is part of GNU Health.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 import csv
 import gettext
+import locale
+from decimal import Decimal
 
-import gtk
+from gi.repository import Gtk
 
 import tryton.common as common
 from tryton.common import RPCExecute, RPCException
+from tryton.common.datetime_ import date_parse
 from tryton.gui.window.win_csv import WinCSV
 
 _ = gettext.gettext
@@ -15,54 +18,56 @@ _ = gettext.gettext
 class WinImport(WinCSV):
     "Window import"
 
-    def __init__(self, model, context):
+    def __init__(self, name, model, context):
+        self.name = name
         self.model = model
         self.context = context
         self.fields_data = {}
         self.fields = {}
         self.fields_invert = {}
         super(WinImport, self).__init__()
-        self.dialog.set_title(_('Import from CSV'))
-
-    def add_header(self, box):
-        pass
+        self.dialog.set_title(_('CSV Import: %s') % name)
 
     def add_buttons(self, box):
-        button_autodetect = gtk.Button(
-            _('_Auto-Detect'), stock=None, use_underline=True)
-        button_autodetect.set_alignment(0.0, 0.0)
-        img_button = gtk.Image()
-        img_button.set_from_stock('tryton-find', gtk.ICON_SIZE_BUTTON)
-        button_autodetect.set_image(img_button)
+        button_autodetect = Gtk.Button(
+            label=_('_Auto-Detect'), stock=None, use_underline=True)
+        button_autodetect.set_image(common.IconFactory.get_image(
+                'tryton-search', Gtk.IconSize.BUTTON))
+        button_autodetect.set_always_show_image(True)
         button_autodetect.connect_after('clicked', self.sig_autodetect)
-        box.pack_start(button_autodetect, False, False, 0)
+        box.pack_start(
+            button_autodetect, expand=False, fill=False, padding=0)
 
     def add_chooser(self, box):
-        hbox_csv_import = gtk.HBox()
-        box.pack_start(hbox_csv_import, False, True, 4)
-        label_csv_import = gtk.Label(_("File to Import:"))
+        hbox_csv_import = Gtk.HBox()
+        box.pack_start(hbox_csv_import, expand=False, fill=True, padding=4)
+        label_csv_import = Gtk.Label(label=_("File to Import:"))
         hbox_csv_import.pack_start(label_csv_import, False, False, 0)
-        self.import_csv_file = gtk.FileChooserButton(_("Open..."))
+        self.import_csv_file = Gtk.FileChooserButton(title=_("Open..."))
         label_csv_import.set_mnemonic_widget(self.import_csv_file)
-        hbox_csv_import.pack_start(self.import_csv_file, True, True, 0)
+        hbox_csv_import.pack_start(
+            self.import_csv_file, expand=True, fill=True, padding=0)
 
-    def add_csv_header_param(self, table):
-        label_csv_skip = gtk.Label(_('Lines to Skip:'))
-        label_csv_skip.set_alignment(1, 0.5)
-        table.attach(label_csv_skip, 2, 3, 1, 2)
+    def add_csv_header_param(self, box):
+        label_csv_skip = Gtk.Label(
+            label=_('Lines to Skip:'), halign=Gtk.Align.START)
+        box.pack_start(label_csv_skip, expand=False, fill=True, padding=0)
 
-        self.csv_skip = gtk.SpinButton()
-        self.csv_skip.configure(gtk.Adjustment(0, 0, 100, 1, 10), 1, 0)
+        self.csv_skip = Gtk.SpinButton()
+        self.csv_skip.configure(Gtk.Adjustment(
+                value=0, lower=0, upper=100,
+                step_increment=1, page_increment=10),
+            1, 0)
         label_csv_skip.set_mnemonic_widget(self.csv_skip)
-        table.attach(self.csv_skip, 3, 4, 1, 2)
+        box.pack_start(self.csv_skip, expand=False, fill=True, padding=0)
 
     def model_populate(self, fields, parent_node=None, prefix_field='',
             prefix_name=''):
-        fields_order = fields.keys()
-        fields_order.sort(lambda x, y: -cmp(fields[x].get('string', ''),
-                fields[y].get('string', '')))
+        fields_order = list(fields.keys())
+        fields_order.sort(
+            key=lambda x: fields[x].get('string', ''), reverse=True)
         for field in fields_order:
-            if not fields[field].get('readonly', False):
+            if not fields[field].get('readonly', False) or field == 'id':
                 self.fields_data[prefix_field + field] = fields[field]
                 name = fields[field]['string'] or field
                 node = self.model1.insert(
@@ -103,21 +108,20 @@ class WinImport(WinCSV):
             common.message(_('You must select an import file first.'))
             return True
 
+        encoding = self.get_encoding()
         self.csv_skip.set_value(1)
         try:
             data = csv.reader(
-                open(fname, 'rb'),
+                open(fname, 'r', encoding=encoding, newline=''),
                 quotechar=self.get_quotechar(),
                 delimiter=self.get_delimiter())
         except IOError:
             common.warning(_('Error opening CSV file'), _('Error'))
             return True
         self.sig_unsel_all()
-        encoding = self.get_encoding()
         word = ''
         for line in data:
             for word in line:
-                word = word.decode(encoding)
                 if word not in self.fields_invert and word not in self.fields:
                     iter = self.model1.get_iter_first()
                     prefix = ''
@@ -166,7 +170,7 @@ class WinImport(WinCSV):
         self.model2.clear()
 
     def response(self, dialog, response):
-        if response == gtk.RESPONSE_OK:
+        if response == Gtk.ResponseType.OK:
             fields = []
             iter = self.model2.get_iter_first()
             while iter:
@@ -182,15 +186,29 @@ class WinImport(WinCSV):
         # TODO: make it works with references
         skip = self.csv_skip.get_value_as_int()
         encoding = self.get_encoding()
+        locale_format = self.csv_locale.get_active()
         reader = csv.reader(
-            open(fname, 'rb'),
+            open(fname, 'r', encoding=encoding),
             quotechar=self.get_quotechar(),
             delimiter=self.get_delimiter())
         data = []
         for i, line in enumerate(reader):
             if i < skip or not line:
                 continue
-            data.append([x.decode(encoding).encode('utf-8') for x in line])
+            row = []
+            for field, val in zip(fields, line):
+                if locale_format and val:
+                    type_ = self.fields_data[field]['type']
+                    if type_ in ['integer', 'biginteger']:
+                        val = locale.atoi(val)
+                    elif type_ == 'float':
+                        val = locale.atof(val)
+                    elif type_ == 'numeric':
+                        val = locale.atof(val, Decimal)
+                    elif type_ in ['date', 'datetime']:
+                        val = date_parse(val, common.date_format())
+                row.append(val)
+            data.append(row)
         try:
             count = RPCExecute(
                 'model', self.model, 'import_data', fields, data,
